==> janrain_connect-8.x-1.0.tar.gz: janrain_connect/src/Form/JanrainConnectSettingsForm.php <==
<?php

namespace Drupal\janrain_connect\Form;

use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\janrain_connect\Service\JanrainConnectFlowExtractorService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\janrain_connect\Constants\JanrainConnectWebServiceConstants;

/**
 * Form for configure messages.
 */
class JanrainConnectSettingsForm extends ConfigFormBase {

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * JanrainConnectFlowExtractorService.
   *
   * @var Drupal\janrain_connect\Service\JanrainConnectFlowExtractorService
   */
  private $janrainConnectFlowExtractorService;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    JanrainConnectFlowExtractorService $janrain_connect_flow_extractor_service,
    LanguageManagerInterface $language_manager
  ) {
    $this->janrainConnectFlowExtractorService = $janrain_connect_flow_extractor_service;
    $this->languageManager = $language_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
        $container->get('janrain_connect.flow_extractor'),
        $container->get('language_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'janrain_connect_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'janrain_connect.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('janrain_connect.settings');
    $flow_name = $config->get('flow_name');
    $flow_version = $config->get('flow_version');
    $default_language = $config->get('default_language');
    $languages = $this->languageManager->getLanguages();

    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('General'),
      '#open' => TRUE,
    ];

    $form['general']['application_id'] = [
      '#title' => $this->t('Application ID'),
      '#type' => 'textfield',
      '#default_value' => $config->get('application_id'),
      '#required' => TRUE,
    ];

    $form['general']['client_id'] = [
      '#title' => $this->t('Client ID'),
      '#type' => 'textfield',
      '#description' => $this->t('The API Client ID is a credential login_client that will be used to authenticate the call.'),
      '#default_value' => $config->get('client_id'),
    ];

    $form['general']['capture_server_url'] = [
      '#title' => $this->t('Capture Server URL'),
      '#type' => 'textfield',
      '#default_value' => $config->get('capture_server_url'),
      '#description' => $this->t('https://<b>my-app</b>.janraincapture.com'),
      '#required' => TRUE,
    ];

    $form['general']['entity_type'] = [
      '#title' => $this->t('Entity Type'),
      '#type' => 'textfield',
      '#default_value' => $config->get('entity_type'),
    ];

    $form['flow_info'] = [
      '#type' => 'details',
      '#title' => $this->t('Flow Info'),
      '#open' => TRUE,
    ];

    $form['flow_info']['flow_name'] = [
      '#title' => $this->t('Flow Name'),
      '#type' => 'textfield',
      '#default_value' => $config->get('flow_name'),
      '#description' => $this->t('If blank the value will be <b>@flow_name@</b>', [
        '@flow_name@' => $flow_name,
      ]),
    ];

    $form['flow_info']['flow_version'] = [
      '#title' => $this->t('Flow Version'),
      '#type' => 'textfield',
      '#description' => $this->t('Enter the flow version.'),
      '#default_value' => $flow_version,
      '#required' => TRUE,
    ];

    $form['flow_languages'] = [
      '#type' => 'details',
      '#title' => $this->t('Languages'),
      '#open' => TRUE,
    ];

    foreach ($languages as $language) {

      $flow_language_key = 'flow_language_mapping_';

      $language_name = $language->getName();

      $lid = $language->getId();

      $flow_language_key = $flow_language_key . $lid;

      $form['flow_languages'][$flow_language_key] = [
        '#title' => $language_name . ' (' . $lid . ')',
        '#type' => 'textfield',
        '#default_value' => $config->get($flow_language_key),
        '#description' => $this->t('The janrain lang code which refers to this language. If blank the value will be <b>@default_language@</b>', [
          '@default_language@' => $default_language,
        ]),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    parent::submitForm($form, $form_state);

    $config = $this->config('janrain_connect.settings');
    $flow_name = $config->get('flow_name');
    $default_language = $config->get('default_language');
    $flow_version = $form_state->getValue('flow_version');
    $capture_server_url = $form_state->getValue('capture_server_url');

    if (!empty($form_state->getValue('flow_name'))) {
      $flow_name = $form_state->getValue('flow_name');
    }

    $languages = $this->languageManager->getLanguages();

    foreach ($languages as $language) {

      $value = $default_language;

      $flow_language_key = 'flow_language_mapping_';

      $lid = $language->getId();

      $flow_language_key = $flow_language_key . $lid;

      if (!empty($form_state->getValue($flow_language_key))) {
        $value = $form_state->getValue($flow_language_key);
      }

      $config->set($flow_language_key, $value);
    }

    $config->set('application_id', $form_state->getValue('application_id'));
    $config->set('flow_name', $flow_name);
    $config->set('client_id', $form_state->getValue('client_id'));
    $config->set('flowjs_url', JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FLOW_JS);
    $config->set('flow_version', $flow_version);
    $config->set('app_url', $this->getRequest()->getSchemeAndHttpHost());
    $config->set('capture_server_url', $capture_server_url);
    $config->set('entity_type', $form_state->getValue('entity_type'));
    $config->save();
  }

}

==> janrain_connect-8.x-1.1.tar.gz: janrain_connect/src/Form/JanrainConnectSettingsForm.php <==
<?php

namespace Drupal\janrain_connect\Form;

use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\janrain_connect\Service\JanrainConnectFlowExtractorService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\janrain_connect\Constants\JanrainConnectWebServiceConstants;

/**
 * Form for configure messages.
 */
class JanrainConnectSettingsForm extends ConfigFormBase {

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * JanrainConnectFlowExtractorService.
   *
   * @var Drupal\janrain_connect\Service\JanrainConnectFlowExtractorService
   */
  private $janrainConnectFlowExtractorService;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    JanrainConnectFlowExtractorService $janrain_connect_flow_extractor_service,
    LanguageManagerInterface $language_manager
  ) {
    $this->janrainConnectFlowExtractorService = $janrain_connect_flow_extractor_service;
    $this->languageManager = $language_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
        $container->get('janrain_connect.flow_extractor'),
        $container->get('language_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'janrain_connect_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'janrain_connect.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('janrain_connect.settings');
    $flow_name = $config->get('flow_name');
    $flow_version = $config->get('flow_version');
    $default_language = $config->get('default_language');
    $languages = $this->languageManager->getLanguages();

    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('General'),
      '#open' => TRUE,
    ];

    $form['general']['application_id'] = [
      '#title' => $this->t('Application ID'),
      '#type' => 'textfield',
      '#default_value' => $config->get('application_id'),
      '#description' => $this->t('Enter your Janrain Application ID.'),
      '#required' => TRUE,
    ];

    $form['general']['client_id'] = [
      '#title' => $this->t('Client ID'),
      '#type' => 'textfield',
      '#default_value' => $config->get('client_id'),
      '#description' => $this->t('It is recommended that you use an API Client with login_client role for security reasons.'),
    ];

    $form['general']['capture_server_url'] = [
      '#title' => $this->t('Capture Server URL'),
      '#type' => 'textfield',
      '#default_value' => $config->get('capture_server_url'),
      '#description' => $this->t('https://my-app.janraincapture.com'),
      '#required' => TRUE,
    ];

    $form['general']['entity_type'] = [
      '#title' => $this->t('Entity Type'),
      '#type' => 'textfield',
      '#default_value' => $config->get('entity_type'),
      '#description' => $this->t('Enter the Janrain Entity Type that users will be saved in.'),
    ];

    $form['flow_info'] = [
      '#type' => 'details',
      '#title' => $this->t('Flow Info'),
      '#open' => TRUE,
    ];

    $form['flow_info']['flow_name'] = [
      '#title' => $this->t('Flow Name'),
      '#type' => 'textfield',
      '#default_value' => $config->get('flow_name'),
      '#description' => $this->t('If blank the value will be <b>@flow_name@</b>', [
        '@flow_name@' => $flow_name,
      ]),
    ];

    $form['flow_info']['flow_version'] = [
      '#title' => $this->t('Flow Version'),
      '#type' => 'textfield',
      '#description' => $this->t('Enter the flow version. Currently HEAD is not accepted in Auth API.'),
      '#default_value' => $flow_version,
      '#required' => TRUE,
    ];

    $form['flow_languages'] = [
      '#type' => 'details',
      '#title' => $this->t('Languages'),
      '#open' => TRUE,
    ];

    foreach ($languages as $language) {

      $flow_language_key = 'flow_language_mapping_';

      $language_name = $language->getName();

      $lid = $language->getId();

      $flow_language_key = $flow_language_key . $lid;

      $form['flow_languages'][$flow_language_key] = [
        '#title' => $language_name . ' (' . $lid . ')',
        '#type' => 'textfield',
        '#default_value' => $config->get($flow_language_key),
        '#description' => $this->t('The janrain lang code which refers to this language. If blank the value will be <b>@default_language@</b>', [
          '@default_language@' => $default_language,
        ]),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    parent::submitForm($form, $form_state);

    $config = $this->config('janrain_connect.settings');
    $flow_name = $config->get('flow_name');
    $default_language = $config->get('default_language');
    $flow_version = $form_state->getValue('flow_version');
    $capture_server_url = $form_state->getValue('capture_server_url');

    if (!empty($form_state->getValue('flow_name'))) {
      $flow_name = $form_state->getValue('flow_name');
    }

    $languages = $this->languageManager->getLanguages();

    foreach ($languages as $language) {

      $value = $default_language;

      $flow_language_key = 'flow_language_mapping_';

      $lid = $language->getId();

      $flow_language_key = $flow_language_key . $lid;

      if (!empty($form_state->getValue($flow_language_key))) {
        $value = $form_state->getValue($flow_language_key);
      }

      $config->set($flow_language_key, $value);
    }

    $config->set('application_id', $form_state->getValue('application_id'));
    $config->set('flow_name', $flow_name);
    $config->set('client_id', $form_state->getValue('client_id'));
    $config->set('flowjs_url', JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FLOW_JS);
    $config->set('flow_version', $flow_version);
    $config->set('app_url', $this->getRequest()->getSchemeAndHttpHost());
    $config->set('capture_server_url', $capture_server_url);
    $config->set('entity_type', $form_state->getValue('entity_type'));
    $config->save();
  }

}
